@@ -6,10 +6,7 @@ class BuildStatusWidget(Widget):
     title = ''
     updated_at = ''
     buildnumber = 0
-    status = 0
-
-    def is_building(self):
-        return False
+    buildstatus = 'progress'
 
     def get_title(self):
         return self.title
@@ -18,18 +15,15 @@ class BuildStatusWidget(Widget):
         return self.updated_at
 
     def get_buildnumber(self):
-        if self.is_building:
-            return "..."
-        else:
-            return self.buildnumber
+        return self.buildnumber
 
-    def get_status(self):
-        return self.status
+    def get_buildstatus(self):
+        return self.buildstatus
 
     def get_context(self):
         return {
             'title': self.get_title(),
-            'updated_at': self.get_updated_at(),
-            'buildnumber': self.get_buildnumber(),
-            'status': self.get_status(),
+            'updatedAt': self.get_updated_at(),
+            'buildNumber': self.get_buildnumber(),
+            'buildStatus': self.get_buildstatus(),
         }
